#!/bin/bash
# -------
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along 
# with this program; if not, write to the Free Software Foundation, Inc., 
# 51 Franklin St, Fifth Floor, Boston MA 02110-1301 USA
# --------

set -e

#EXISTS AND THE VALUES ARE UNCHANGED
exists_and_unchanged(){

	if llxcfg-archivevars LDAP test &>/dev/null ; then
		return 0
	fi
	return 1
}

remove_ldap_vars(){
   llxcfg-archivevars LDAP remove
}

store_ldap_vars(){
   llxcfg-archivevars LDAP store LDAP_BASE_DN LDAP_PEOPLE LDAP_GROUP LDAP_VARIABLES LDAP_PROFILES LDAP_ADMIN LDAP_SYSTEM LDAP_MANAGED LDAP_TEACHERS LDAP_NEXT_ID \
                                 LDAP_GROUP_BASE_DN LDAP_PROFILES_GROUP_BASE_DN LDAP_PEOPLE_BASE_DN LDAP_VARIABLES_BASE_DN LDAP_ADMIN_PEOPLE_BASE_DN LDAP_SYSTEM_GROUP_BASE_DN \
                                 LDAP_MANAGED_GROUP_BASE_DN LDAP_TEACHERS_PEOPLE_BASE_DN
}

building_ldap_vars(){

        eval $(llxcfg-showvars LDAP_BASE_DN SRV_IP CAP_NET_HOST_IP)

        [ "$LDAP_BASE_DN" ] || exit_message "LDAP Base DN not Present..Exiting"

	LDAP_SERVICES=""
	for a in 127.0.0.1 $SRV_IP $CAP_NET_HOST_IP ; do
		lliurex-net is_current_ip "$a" || continue
		for p in ldaps ldap ; do
			u="${p}://${a}/"
			if ! echo "$LDAP_SERVICES" |grep -q "$u" ; then
				LDAP_SERVICES="$LDAP_SERVICES $u"
			fi
		done
	done
		

        llxcfg-systemvars add LDAP_PEOPLE="ou=People," \
                              LDAP_GROUP="ou=Group," \
                              LDAP_VARIABLES="ou=Variables," \
                              LDAP_PROFILES="ou=Profiles," \
                              LDAP_ADMIN="ou=Admin," \
                              LDAP_SYSTEM="ou=System," \
                              LDAP_MANAGED="ou=Managed," \
                              LDAP_TEACHERS="ou=Teachers," \
                              LDAP_NEXT_ID=11000 \
			      LDAP_SERVICES="$LDAP_SERVICES"

#	llxcfg-systemvars add LLIUREX_MA="ma2"

        eval $(llxcfg-showvars LDAP_SERVICES LDAP_PEOPLE LDAP_GROUP LDAP_VARIABLES LDAP_PROFILES LDAP_ADMIN LDAP_SYSTEM LDAP_MANAGED LDAP_TEACHERS LDAP_NEXT_ID LDAP_BASE_DN LDAP_SRV_MODE LDAP_MASTER_URI)
	
	LWAT_LDAP_SRV="$SRV_IP"
	LDAP_SERVICES=$(echo $LDAP_SERVICES)
	LDAP_URI="${LDAP_SERVICES%% *}"
	LDAP_URI_NOSSL="ldap://127.0.0.1/"

        llxcfg-systemvars add LDAP_URI="$LDAP_URI" \
                              LDAP_URI_NOSSL="$LDAP_URI_NOSSL" \
                              LWAT_LDAP_SRV="$LWAT_LDAP_SRV" \
			      LDAP_GROUP_BASE_DN="${LDAP_GROUP}${LDAP_BASE_DN}"
        eval $(llxcfg-showvars LDAP_GROUP_BASE_DN)
        llxcfg-systemvars add LDAP_PROFILES_GROUP_BASE_DN="${LDAP_PROFILES}${LDAP_GROUP_BASE_DN}" \
                              LDAP_PEOPLE_BASE_DN="${LDAP_PEOPLE}${LDAP_BASE_DN}"
        eval $(llxcfg-showvars LDAP_PEOPLE_BASE_DN)
        llxcfg-systemvars add LDAP_VARIABLES_BASE_DN="${LDAP_VARIABLES}${LDAP_BASE_DN}" \
                              LDAP_ADMIN_PEOPLE_BASE_DN="${LDAP_ADMIN}${LDAP_PEOPLE_BASE_DN}" \
                              LDAP_SYSTEM_GROUP_BASE_DN="${LDAP_SYSTEM}${LDAP_GROUP_BASE_DN}" \
                              LDAP_MANAGED_GROUP_BASE_DN="${LDAP_MANAGED}${LDAP_GROUP_BASE_DN}" \
                              LDAP_TEACHERS_PEOPLE_BASE_DN="${LDAP_TEACHERS}${LDAP_PEOPLE_BASE_DN}"

}

#
# COPIED FROM ARCANE LDAP TOOLS
#

llxcfg_is_valid_LWAT_LDAP_DN() {
  

	eval $(llxcfg-showvars LDAP_BASE_DN)
	local alp='A-Za-z'
  	local dig='0-9'
  	local hex='0-9A-Fa-f'
  	local quo='"'
  	local bs='\\'
  	local dot='\.'
  	local spe=',=+<>#;'
  
  	local typeStr="[$alp][$alp$dig-]*"
  	local oid="[$dig]\+\($dot[$dig]\+\)*"
 	local attType="\($typeStr\)\|\($oid\)"
  
  	local string="\([^$bs$quo$spe]\|$bs\([$bs$quo$spe]\|[$hex][$hex]\)\)*"
  	local hexstr="\#\([$hex][$hex]\)\+"
  	local quostr="\"\([^$bs$quo]\|$bs\([$bs$quo$spe]\|[$hex][$hex]\)\)*\""
  	local attValue="\($string\)\|\($hexstr\)\|\($quostr\)"
  
  	local name="\($attType\)=\($attValue\)"
  	local dn_regex="$name\(,$name\)*"
  
  	DN="`echo "$LDAP_BASE_DN" | grep "^\($dn_regex\)$"`"
  	test -n "$DN"
  	temp=$(echo "$DN" | sed -n "/^dc=/p")
  	[ -z ${temp} ] && return 0 
  	return 1
}

generate_new_codigo_centro(){

	eval $(llxcfg-showvars LDAP_BASE_DN)
	llxcfg-systemvars add TMP_CODIGO_CENTRO="`echo $LDAP_BASE_DN |  sed -e "s%[[:blank:]]%%;s%,.*$%%;s%^dc=%%g"`"
}



building_base_dn(){


 	# ok, LDAP_BASE_DN is empty but we have the ingredients ...
	eval $(llxcfg-showvars LDAP_SRV_MODE LDAP_MASTER_BASE_DN LDAP_BASE_DN CODIGO_CENTRO SRV_DOMAIN LLIUREX_MA LLIUREX_SLD)
	if [ "$LDAP_MASTER_BASE_DN" -a "$LDAP_SRV_MODE" = "SLAVE" ] ; then
        	llxcfg-systemvars add LDAP_BASE_DN="$LDAP_MASTER_BASE_DN"
	else
        	LLIUREX_SLD=$(echo $LLIUREX_SLD | sed "s%\.%,dc=%g")
        	llxcfg-systemvars add LDAP_BASE_DN="$(echo "dc=${CODIGO_CENTRO},dc=${SRV_DOMAIN},dc=${LLIUREX_MA},dc=${LLIUREX_SLD}")"
	fi

}



we_have_all_the_ingredients(){

	eval $(llxcfg-showvars CODIGO_CENTRO LLIUREX_MA LLIUREX_SLD SRV_DOMAIN LDAP_MASTER_BASE_DN )
	[ "$LDAP_MASTER_BASE_DN" -a "$LDAP_SRV_MODE" = "SLAVE" ] || [ $CODIGO_CENTRO -a $SRV_DOMAIN -a $LLIUREX_MA -a $LLIUREX_SLD ] || exit_message " ERROR: NOT HAVE ALL INGREDIENTS, REMAIN SOME VALUES...EXITING"
	
}

create_passwd(){
   # skip if already exists
   [ -s "$1" ] && return 0
   pwgen -cns 12 1 |llxcfg-install --mode=400 --owner=root --group=root - "$1" || return 1
   [ -s "$1" ] || return 1
   return 0
}


exit_message(){

	echo $1

	exit 1

}

